==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorStatusFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionFluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1.AddressableFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterInterceptorStatusFluent<A extends ClusterInterceptorStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ClusterInterceptorStatusFluent.AddressNested<A> withNewAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ClusterInterceptorStatusFluent.AddressNested<A> editAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> editOrNewAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> addNewCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editFirstCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editLastCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ClusterInterceptorStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ClusterInterceptorStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorStatusFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionFluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1.AddressableFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterInterceptorStatusFluent<A extends ClusterInterceptorStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ClusterInterceptorStatusFluent.AddressNested<A> withNewAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ClusterInterceptorStatusFluent.AddressNested<A> editAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> editOrNewAddress();
  public ClusterInterceptorStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> addNewCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editCondition(int index);
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editFirstCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editLastCondition();
  public ClusterInterceptorStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ClusterInterceptorStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ClusterInterceptorStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
